@@ -1,7 +1,7 @@
 """Expose submodules."""
 from .base_class import Place
 from .bticino import BNCX, BNDL, BNSL
-from .idiamant import NBG, NBR
+from .idiamant import NBG, NBO, NBR, NBS
 from .legrand import (
     NLC,
     NLD,
@@ -23,7 +23,10 @@ from .legrand import (
     NLPS,
     NLPT,
     NLT,
+    NLUF,
+    NLUI,
     NLV,
+    NLunknown,
 )
 from .module import Camera, Dimmer, Module, Shutter, Switch
 from .netatmo import (
@@ -51,9 +54,9 @@ from .netatmo import (
 from .smarther import BNS
 
 __all__ = [
-    "BNS",
     "BNCX",
     "BNDL",
+    "BNS",
     "BNSL",
     "Camera",
     "Dimmer",
@@ -69,7 +72,9 @@ __all__ = [
     "NAPlug",
     "NATherm1",
     "NBG",
+    "NBO",
     "NBR",
+    "NBS",
     "NCO",
     "NDB",
     "NHC",
@@ -78,8 +83,8 @@ __all__ = [
     "NLD",
     "NLE",
     "NLF",
-    "NLFN",
     "NLFE",
+    "NLFN",
     "NLG",
     "NLIS",
     "NLL",
@@ -94,6 +99,9 @@ __all__ = [
     "NLPS",
     "NLPT",
     "NLT",
+    "NLUF",
+    "NLUI",
+    "NLunknown",
     "NLV",
     "NOC",
     "NRV",
