@@ -104,3 +104,15 @@ class NLPS(FirmwareMixin, PowerMixin, EnergyMixin, Module):
 
 class NLC(FirmwareMixin, SwitchMixin, Module):
     """Legrand / BTicino cable outlet."""
+
+
+class NLUI(FirmwareMixin, Module):
+    """Legrand NLUI device stub."""
+
+
+class NLUF(FirmwareMixin, Module):
+    """Legrand NLUF device stub."""
+
+
+class NLunknown(Module):
+    """NLunknown device stub."""
