@@ -5,6 +5,7 @@ import dataclasses
 from abc import ABC
 from collections import defaultdict
 from typing import Any
+from warnings import warn
 
 from pyatmo.auth import AbstractAsyncAuth, NetatmoOAuth2
 from pyatmo.const import (
@@ -25,6 +26,8 @@ from pyatmo.const import (
 from pyatmo.exceptions import NoDevice
 from pyatmo.modules import Location
 
+warn(f"The module {__name__} is deprecated.", DeprecationWarning, stacklevel=2)
+
 
 class AbstractPublicData(ABC):
     """Class of Netatmo public weather data."""
